# MessageSendResponseItem

Contains the sent message with its guid filled in, as well as any metadata about how the operation proceeded. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**message** | [**Message**](Message.md) |  | 
**count** | **float** | The number of endpoints to which the message was sent | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


